@@ -2,7 +2,7 @@ from django.apps import AppConfig
 
 
 class PaypalPaymentsAppConfig(AppConfig):
-    name = 'plans_paypal'
+    name = "plans_paypal"
 
     def ready(self):
         from . import hooks  # noqa
